export default {
    "type": "Program",
    "loc": {
        "start": {
            "line": 1,
            "column": 0
        },
        "end": {
            "line": 6,
            "column": 1
        }
    },
    "range": [
        0,
        128
    ],
    "body": [
        {
            "type": "ClassDeclaration",
            "loc": {
                "start": {
                    "line": 1,
                    "column": 0
                },
                "end": {
                    "line": 6,
                    "column": 1
                }
            },
            "range": [
                0,
                128
            ],
            "id": {
                "type": "Identifier",
                "loc": {
                    "start": {
                        "line": 1,
                        "column": 6
                    },
                    "end": {
                        "line": 1,
                        "column": 7
                    }
                },
                "range": [
                    6,
                    7
                ],
                "name": "C"
            },
            "superClass": null,
            "body": {
                "type": "ClassBody",
                "loc": {
                    "start": {
                        "line": 1,
                        "column": 8
                    },
                    "end": {
                        "line": 6,
                        "column": 1
                    }
                },
                "range": [
                    8,
                    128
                ],
                "body": [
                    {
                        "type": "MethodDefinition",
                        "loc": {
                            "start": {
                                "line": 2,
                                "column": 4
                            },
                            "end": {
                                "line": 2,
                                "column": 22
                            }
                        },
                        "range": [
                            14,
                            32
                        ],
                        "static": true,
                        "computed": false,
                        "key": {
                            "type": "PrivateIdentifier",
                            "loc": {
                                "start": {
                                    "line": 2,
                                    "column": 11
                                },
                                "end": {
                                    "line": 2,
                                    "column": 18
                                }
                            },
                            "range": [
                                21,
                                28
                            ],
                            "name": "method"
                        },
                        "kind": "method",
                        "value": {
                            "type": "FunctionExpression",
                            "loc": {
                                "start": {
                                    "line": 2,
                                    "column": 18
                                },
                                "end": {
                                    "line": 2,
                                    "column": 22
                                }
                            },
                            "range": [
                                28,
                                32
                            ],
                            "id": null,
                            "expression": false,
                            "generator": false,
                            "async": false,
                            "params": [],
                            "body": {
                                "type": "BlockStatement",
                                "loc": {
                                    "start": {
                                        "line": 2,
                                        "column": 20
                                    },
                                    "end": {
                                        "line": 2,
                                        "column": 22
                                    }
                                },
                                "range": [
                                    30,
                                    32
                                ],
                                "body": []
                            }
                        }
                    },
                    {
                        "type": "MethodDefinition",
                        "loc": {
                            "start": {
                                "line": 3,
                                "column": 4
                            },
                            "end": {
                                "line": 3,
                                "column": 27
                            }
                        },
                        "range": [
                            37,
                            60
                        ],
                        "static": true,
                        "computed": false,
                        "key": {
                            "type": "PrivateIdentifier",
                            "loc": {
                                "start": {
                                    "line": 3,
                                    "column": 13
                                },
                                "end": {
                                    "line": 3,
                                    "column": 23
                                }
                            },
                            "range": [
                                46,
                                56
                            ],
                            "name": "generator"
                        },
                        "kind": "method",
                        "value": {
                            "type": "FunctionExpression",
                            "loc": {
                                "start": {
                                    "line": 3,
                                    "column": 23
                                },
                                "end": {
                                    "line": 3,
                                    "column": 27
                                }
                            },
                            "range": [
                                56,
                                60
                            ],
                            "id": null,
                            "expression": false,
                            "generator": true,
                            "async": false,
                            "params": [],
                            "body": {
                                "type": "BlockStatement",
                                "loc": {
                                    "start": {
                                        "line": 3,
                                        "column": 25
                                    },
                                    "end": {
                                        "line": 3,
                                        "column": 27
                                    }
                                },
                                "range": [
                                    58,
                                    60
                                ],
                                "body": []
                            }
                        }
                    },
                    {
                        "type": "MethodDefinition",
                        "loc": {
                            "start": {
                                "line": 4,
                                "column": 4
                            },
                            "end": {
                                "line": 4,
                                "column": 27
                            }
                        },
                        "range": [
                            65,
                            88
                        ],
                        "static": true,
                        "computed": false,
                        "key": {
                            "type": "PrivateIdentifier",
                            "loc": {
                                "start": {
                                    "line": 4,
                                    "column": 17
                                },
                                "end": {
                                    "line": 4,
                                    "column": 23
                                }
                            },
                            "range": [
                                78,
                                84
                            ],
                            "name": "async"
                        },
                        "kind": "method",
                        "value": {
                            "type": "FunctionExpression",
                            "loc": {
                                "start": {
                                    "line": 4,
                                    "column": 23
                                },
                                "end": {
                                    "line": 4,
                                    "column": 27
                                }
                            },
                            "range": [
                                84,
                                88
                            ],
                            "id": null,
                            "expression": false,
                            "generator": false,
                            "async": true,
                            "params": [],
                            "body": {
                                "type": "BlockStatement",
                                "loc": {
                                    "start": {
                                        "line": 4,
                                        "column": 25
                                    },
                                    "end": {
                                        "line": 4,
                                        "column": 27
                                    }
                                },
                                "range": [
                                    86,
                                    88
                                ],
                                "body": []
                            }
                        }
                    },
                    {
                        "type": "MethodDefinition",
                        "loc": {
                            "start": {
                                "line": 5,
                                "column": 4
                            },
                            "end": {
                                "line": 5,
                                "column": 37
                            }
                        },
                        "range": [
                            93,
                            126
                        ],
                        "static": true,
                        "computed": false,
                        "key": {
                            "type": "PrivateIdentifier",
                            "loc": {
                                "start": {
                                    "line": 5,
                                    "column": 18
                                },
                                "end": {
                                    "line": 5,
                                    "column": 33
                                }
                            },
                            "range": [
                                107,
                                122
                            ],
                            "name": "asyncGenerator"
                        },
                        "kind": "method",
                        "value": {
                            "type": "FunctionExpression",
                            "loc": {
                                "start": {
                                    "line": 5,
                                    "column": 33
                                },
                                "end": {
                                    "line": 5,
                                    "column": 37
                                }
                            },
                            "range": [
                                122,
                                126
                            ],
                            "id": null,
                            "expression": false,
                            "generator": true,
                            "async": true,
                            "params": [],
                            "body": {
                                "type": "BlockStatement",
                                "loc": {
                                    "start": {
                                        "line": 5,
                                        "column": 35
                                    },
                                    "end": {
                                        "line": 5,
                                        "column": 37
                                    }
                                },
                                "range": [
                                    124,
                                    126
                                ],
                                "body": []
                            }
                        }
                    }
                ]
            }
        }
    ],
    "sourceType": "script",
    "tokens": [
        {
            "type": "Keyword",
            "value": "class",
            "loc": {
                "start": {
                    "line": 1,
                    "column": 0
                },
                "end": {
                    "line": 1,
                    "column": 5
                }
            },
            "range": [
                0,
                5
            ]
        },
        {
            "type": "Identifier",
            "value": "C",
            "loc": {
                "start": {
                    "line": 1,
                    "column": 6
                },
                "end": {
                    "line": 1,
                    "column": 7
                }
            },
            "range": [
                6,
                7
            ]
        },
        {
            "type": "Punctuator",
            "value": "{",
            "loc": {
                "start": {
                    "line": 1,
                    "column": 8
                },
                "end": {
                    "line": 1,
                    "column": 9
                }
            },
            "range": [
                8,
                9
            ]
        },
        {
            "type": "Keyword",
            "value": "static",
            "loc": {
                "start": {
                    "line": 2,
                    "column": 4
                },
                "end": {
                    "line": 2,
                    "column": 10
                }
            },
            "range": [
                14,
                20
            ]
        },
        {
            "type": "PrivateIdentifier",
            "value": "method",
            "loc": {
                "start": {
                    "line": 2,
                    "column": 11
                },
                "end": {
                    "line": 2,
                    "column": 18
                }
            },
            "range": [
                21,
                28
            ]
        },
        {
            "type": "Punctuator",
            "value": "(",
            "loc": {
                "start": {
                    "line": 2,
                    "column": 18
                },
                "end": {
                    "line": 2,
                    "column": 19
                }
            },
            "range": [
                28,
                29
            ]
        },
        {
            "type": "Punctuator",
            "value": ")",
            "loc": {
                "start": {
                    "line": 2,
                    "column": 19
                },
                "end": {
                    "line": 2,
                    "column": 20
                }
            },
            "range": [
                29,
                30
            ]
        },
        {
            "type": "Punctuator",
            "value": "{",
            "loc": {
                "start": {
                    "line": 2,
                    "column": 20
                },
                "end": {
                    "line": 2,
                    "column": 21
                }
            },
            "range": [
                30,
                31
            ]
        },
        {
            "type": "Punctuator",
            "value": "}",
            "loc": {
                "start": {
                    "line": 2,
                    "column": 21
                },
                "end": {
                    "line": 2,
                    "column": 22
                }
            },
            "range": [
                31,
                32
            ]
        },
        {
            "type": "Keyword",
            "value": "static",
            "loc": {
                "start": {
                    "line": 3,
                    "column": 4
                },
                "end": {
                    "line": 3,
                    "column": 10
                }
            },
            "range": [
                37,
                43
            ]
        },
        {
            "type": "Punctuator",
            "value": "*",
            "loc": {
                "start": {
                    "line": 3,
                    "column": 11
                },
                "end": {
                    "line": 3,
                    "column": 12
                }
            },
            "range": [
                44,
                45
            ]
        },
        {
            "type": "PrivateIdentifier",
            "value": "generator",
            "loc": {
                "start": {
                    "line": 3,
                    "column": 13
                },
                "end": {
                    "line": 3,
                    "column": 23
                }
            },
            "range": [
                46,
                56
            ]
        },
        {
            "type": "Punctuator",
            "value": "(",
            "loc": {
                "start": {
                    "line": 3,
                    "column": 23
                },
                "end": {
                    "line": 3,
                    "column": 24
                }
            },
            "range": [
                56,
                57
            ]
        },
        {
            "type": "Punctuator",
            "value": ")",
            "loc": {
                "start": {
                    "line": 3,
                    "column": 24
                },
                "end": {
                    "line": 3,
                    "column": 25
                }
            },
            "range": [
                57,
                58
            ]
        },
        {
            "type": "Punctuator",
            "value": "{",
            "loc": {
                "start": {
                    "line": 3,
                    "column": 25
                },
                "end": {
                    "line": 3,
                    "column": 26
                }
            },
            "range": [
                58,
                59
            ]
        },
        {
            "type": "Punctuator",
            "value": "}",
            "loc": {
                "start": {
                    "line": 3,
                    "column": 26
                },
                "end": {
                    "line": 3,
                    "column": 27
                }
            },
            "range": [
                59,
                60
            ]
        },
        {
            "type": "Keyword",
            "value": "static",
            "loc": {
                "start": {
                    "line": 4,
                    "column": 4
                },
                "end": {
                    "line": 4,
                    "column": 10
                }
            },
            "range": [
                65,
                71
            ]
        },
        {
            "type": "Identifier",
            "value": "async",
            "loc": {
                "start": {
                    "line": 4,
                    "column": 11
                },
                "end": {
                    "line": 4,
                    "column": 16
                }
            },
            "range": [
                72,
                77
            ]
        },
        {
            "type": "PrivateIdentifier",
            "value": "async",
            "loc": {
                "start": {
                    "line": 4,
                    "column": 17
                },
                "end": {
                    "line": 4,
                    "column": 23
                }
            },
            "range": [
                78,
                84
            ]
        },
        {
            "type": "Punctuator",
            "value": "(",
            "loc": {
                "start": {
                    "line": 4,
                    "column": 23
                },
                "end": {
                    "line": 4,
                    "column": 24
                }
            },
            "range": [
                84,
                85
            ]
        },
        {
            "type": "Punctuator",
            "value": ")",
            "loc": {
                "start": {
                    "line": 4,
                    "column": 24
                },
                "end": {
                    "line": 4,
                    "column": 25
                }
            },
            "range": [
                85,
                86
            ]
        },
        {
            "type": "Punctuator",
            "value": "{",
            "loc": {
                "start": {
                    "line": 4,
                    "column": 25
                },
                "end": {
                    "line": 4,
                    "column": 26
                }
            },
            "range": [
                86,
                87
            ]
        },
        {
            "type": "Punctuator",
            "value": "}",
            "loc": {
                "start": {
                    "line": 4,
                    "column": 26
                },
                "end": {
                    "line": 4,
                    "column": 27
                }
            },
            "range": [
                87,
                88
            ]
        },
        {
            "type": "Keyword",
            "value": "static",
            "loc": {
                "start": {
                    "line": 5,
                    "column": 4
                },
                "end": {
                    "line": 5,
                    "column": 10
                }
            },
            "range": [
                93,
                99
            ]
        },
        {
            "type": "Identifier",
            "value": "async",
            "loc": {
                "start": {
                    "line": 5,
                    "column": 11
                },
                "end": {
                    "line": 5,
                    "column": 16
                }
            },
            "range": [
                100,
                105
            ]
        },
        {
            "type": "Punctuator",
            "value": "*",
            "loc": {
                "start": {
                    "line": 5,
                    "column": 16
                },
                "end": {
                    "line": 5,
                    "column": 17
                }
            },
            "range": [
                105,
                106
            ]
        },
        {
            "type": "PrivateIdentifier",
            "value": "asyncGenerator",
            "loc": {
                "start": {
                    "line": 5,
                    "column": 18
                },
                "end": {
                    "line": 5,
                    "column": 33
                }
            },
            "range": [
                107,
                122
            ]
        },
        {
            "type": "Punctuator",
            "value": "(",
            "loc": {
                "start": {
                    "line": 5,
                    "column": 33
                },
                "end": {
                    "line": 5,
                    "column": 34
                }
            },
            "range": [
                122,
                123
            ]
        },
        {
            "type": "Punctuator",
            "value": ")",
            "loc": {
                "start": {
                    "line": 5,
                    "column": 34
                },
                "end": {
                    "line": 5,
                    "column": 35
                }
            },
            "range": [
                123,
                124
            ]
        },
        {
            "type": "Punctuator",
            "value": "{",
            "loc": {
                "start": {
                    "line": 5,
                    "column": 35
                },
                "end": {
                    "line": 5,
                    "column": 36
                }
            },
            "range": [
                124,
                125
            ]
        },
        {
            "type": "Punctuator",
            "value": "}",
            "loc": {
                "start": {
                    "line": 5,
                    "column": 36
                },
                "end": {
                    "line": 5,
                    "column": 37
                }
            },
            "range": [
                125,
                126
            ]
        },
        {
            "type": "Punctuator",
            "value": "}",
            "loc": {
                "start": {
                    "line": 6,
                    "column": 0
                },
                "end": {
                    "line": 6,
                    "column": 1
                }
            },
            "range": [
                127,
                128
            ]
        }
    ]
};