// !x
export default [
    {
        "type": "Punctuator",
        "value": "!",
        "range": [
            0,
            1
        ],
        "loc": {
            "start": {
                "line": 1,
                "column": 0
            },
            "end": {
                "line": 1,
                "column": 1
            }
        }
    },
    {
        "type": "Identifier",
        "value": "x",
        "range": [
            1,
            2
        ],
        "loc": {
            "start": {
                "line": 1,
                "column": 1
            },
            "end": {
                "line": 1,
                "column": 2
            }
        }
    }
];
