export default {
    "type": "Program",
    "loc": {
        "start": {
            "line": 1,
            "column": 0
        },
        "end": {
            "line": 7,
            "column": 1
        }
    },
    "range": [
        0,
        63
    ],
    "body": [
        {
            "type": "ClassDeclaration",
            "loc": {
                "start": {
                    "line": 1,
                    "column": 0
                },
                "end": {
                    "line": 7,
                    "column": 1
                }
            },
            "range": [
                0,
                63
            ],
            "id": {
                "type": "Identifier",
                "loc": {
                    "start": {
                        "line": 1,
                        "column": 6
                    },
                    "end": {
                        "line": 1,
                        "column": 7
                    }
                },
                "range": [
                    6,
                    7
                ],
                "name": "C"
            },
            "superClass": null,
            "body": {
                "type": "ClassBody",
                "loc": {
                    "start": {
                        "line": 1,
                        "column": 8
                    },
                    "end": {
                        "line": 7,
                        "column": 1
                    }
                },
                "range": [
                    8,
                    63
                ],
                "body": [
                    {
                        "type": "PropertyDefinition",
                        "loc": {
                            "start": {
                                "line": 2,
                                "column": 4
                            },
                            "end": {
                                "line": 2,
                                "column": 7
                            }
                        },
                        "range": [
                            14,
                            17
                        ],
                        "static": false,
                        "computed": false,
                        "key": {
                            "type": "Literal",
                            "loc": {
                                "start": {
                                    "line": 2,
                                    "column": 4
                                },
                                "end": {
                                    "line": 2,
                                    "column": 7
                                }
                            },
                            "range": [
                                14,
                                17
                            ],
                            "value": 1000,
                            "raw": "1e3"
                        },
                        "value": null
                    },
                    {
                        "type": "PropertyDefinition",
                        "loc": {
                            "start": {
                                "line": 3,
                                "column": 4
                            },
                            "end": {
                                "line": 3,
                                "column": 12
                            }
                        },
                        "range": [
                            22,
                            30
                        ],
                        "static": false,
                        "computed": false,
                        "key": {
                            "type": "Literal",
                            "loc": {
                                "start": {
                                    "line": 3,
                                    "column": 4
                                },
                                "end": {
                                    "line": 3,
                                    "column": 12
                                }
                            },
                            "range": [
                                22,
                                30
                            ],
                            "value": "double",
                            "raw": "\"double\""
                        },
                        "value": null
                    },
                    {
                        "type": "PropertyDefinition",
                        "loc": {
                            "start": {
                                "line": 4,
                                "column": 4
                            },
                            "end": {
                                "line": 4,
                                "column": 12
                            }
                        },
                        "range": [
                            35,
                            43
                        ],
                        "static": false,
                        "computed": false,
                        "key": {
                            "type": "Literal",
                            "loc": {
                                "start": {
                                    "line": 4,
                                    "column": 4
                                },
                                "end": {
                                    "line": 4,
                                    "column": 12
                                }
                            },
                            "range": [
                                35,
                                43
                            ],
                            "value": "single",
                            "raw": "'single'"
                        },
                        "value": null
                    },
                    {
                        "type": "PropertyDefinition",
                        "loc": {
                            "start": {
                                "line": 5,
                                "column": 4
                            },
                            "end": {
                                "line": 5,
                                "column": 6
                            }
                        },
                        "range": [
                            48,
                            50
                        ],
                        "static": false,
                        "computed": false,
                        "key": {
                            "type": "Literal",
                            "loc": {
                                "start": {
                                    "line": 5,
                                    "column": 4
                                },
                                "end": {
                                    "line": 5,
                                    "column": 6
                                }
                            },
                            "range": [
                                48,
                                50
                            ],
                            "value": 1n,
                            "raw": "1n",
                            "bigint": "1"
                        },
                        "value": null
                    },
                    {
                        "type": "PropertyDefinition",
                        "loc": {
                            "start": {
                                "line": 6,
                                "column": 4
                            },
                            "end": {
                                "line": 6,
                                "column": 10
                            }
                        },
                        "range": [
                            55,
                            61
                        ],
                        "static": false,
                        "computed": false,
                        "key": {
                            "type": "Identifier",
                            "loc": {
                                "start": {
                                    "line": 6,
                                    "column": 4
                                },
                                "end": {
                                    "line": 6,
                                    "column": 10
                                }
                            },
                            "range": [
                                55,
                                61
                            ],
                            "name": "A"
                        },
                        "value": null
                    }
                ]
            }
        }
    ],
    "sourceType": "script",
    "tokens": [
        {
            "type": "Keyword",
            "value": "class",
            "loc": {
                "start": {
                    "line": 1,
                    "column": 0
                },
                "end": {
                    "line": 1,
                    "column": 5
                }
            },
            "range": [
                0,
                5
            ]
        },
        {
            "type": "Identifier",
            "value": "C",
            "loc": {
                "start": {
                    "line": 1,
                    "column": 6
                },
                "end": {
                    "line": 1,
                    "column": 7
                }
            },
            "range": [
                6,
                7
            ]
        },
        {
            "type": "Punctuator",
            "value": "{",
            "loc": {
                "start": {
                    "line": 1,
                    "column": 8
                },
                "end": {
                    "line": 1,
                    "column": 9
                }
            },
            "range": [
                8,
                9
            ]
        },
        {
            "type": "Numeric",
            "value": "1e3",
            "loc": {
                "start": {
                    "line": 2,
                    "column": 4
                },
                "end": {
                    "line": 2,
                    "column": 7
                }
            },
            "range": [
                14,
                17
            ]
        },
        {
            "type": "String",
            "value": "\"double\"",
            "loc": {
                "start": {
                    "line": 3,
                    "column": 4
                },
                "end": {
                    "line": 3,
                    "column": 12
                }
            },
            "range": [
                22,
                30
            ]
        },
        {
            "type": "String",
            "value": "'single'",
            "loc": {
                "start": {
                    "line": 4,
                    "column": 4
                },
                "end": {
                    "line": 4,
                    "column": 12
                }
            },
            "range": [
                35,
                43
            ]
        },
        {
            "type": "Numeric",
            "value": "1n",
            "loc": {
                "start": {
                    "line": 5,
                    "column": 4
                },
                "end": {
                    "line": 5,
                    "column": 6
                }
            },
            "range": [
                48,
                50
            ]
        },
        {
            "type": "Identifier",
            "value": "A",
            "loc": {
                "start": {
                    "line": 6,
                    "column": 4
                },
                "end": {
                    "line": 6,
                    "column": 10
                }
            },
            "range": [
                55,
                61
            ]
        },
        {
            "type": "Punctuator",
            "value": "}",
            "loc": {
                "start": {
                    "line": 7,
                    "column": 0
                },
                "end": {
                    "line": 7,
                    "column": 1
                }
            },
            "range": [
                62,
                63
            ]
        }
    ]
};