export default {
    "type": "Program",
    "loc": {
        "start": {
            "line": 1,
            "column": 0
        },
        "end": {
            "line": 5,
            "column": 1
        }
    },
    "range": [
        0,
        42
    ],
    "body": [
        {
            "type": "ClassDeclaration",
            "loc": {
                "start": {
                    "line": 1,
                    "column": 0
                },
                "end": {
                    "line": 5,
                    "column": 1
                }
            },
            "range": [
                0,
                42
            ],
            "id": {
                "type": "Identifier",
                "loc": {
                    "start": {
                        "line": 1,
                        "column": 6
                    },
                    "end": {
                        "line": 1,
                        "column": 7
                    }
                },
                "range": [
                    6,
                    7
                ],
                "name": "C"
            },
            "superClass": null,
            "body": {
                "type": "ClassBody",
                "loc": {
                    "start": {
                        "line": 1,
                        "column": 8
                    },
                    "end": {
                        "line": 5,
                        "column": 1
                    }
                },
                "range": [
                    8,
                    42
                ],
                "body": [
                    {
                        "type": "PropertyDefinition",
                        "loc": {
                            "start": {
                                "line": 2,
                                "column": 4
                            },
                            "end": {
                                "line": 2,
                                "column": 8
                            }
                        },
                        "range": [
                            14,
                            18
                        ],
                        "static": false,
                        "computed": false,
                        "key": {
                            "type": "PrivateIdentifier",
                            "loc": {
                                "start": {
                                    "line": 2,
                                    "column": 4
                                },
                                "end": {
                                    "line": 2,
                                    "column": 8
                                }
                            },
                            "range": [
                                14,
                                18
                            ],
                            "name": "aaa"
                        },
                        "value": null
                    },
                    {
                        "type": "PropertyDefinition",
                        "loc": {
                            "start": {
                                "line": 3,
                                "column": 4
                            },
                            "end": {
                                "line": 3,
                                "column": 12
                            }
                        },
                        "range": [
                            23,
                            31
                        ],
                        "static": false,
                        "computed": false,
                        "key": {
                            "type": "PrivateIdentifier",
                            "loc": {
                                "start": {
                                    "line": 3,
                                    "column": 4
                                },
                                "end": {
                                    "line": 3,
                                    "column": 8
                                }
                            },
                            "range": [
                                23,
                                27
                            ],
                            "name": "bbb"
                        },
                        "value": {
                            "type": "Literal",
                            "loc": {
                                "start": {
                                    "line": 3,
                                    "column": 11
                                },
                                "end": {
                                    "line": 3,
                                    "column": 12
                                }
                            },
                            "range": [
                                30,
                                31
                            ],
                            "value": 0,
                            "raw": "0"
                        }
                    },
                    {
                        "type": "PropertyDefinition",
                        "loc": {
                            "start": {
                                "line": 4,
                                "column": 4
                            },
                            "end": {
                                "line": 4,
                                "column": 8
                            }
                        },
                        "range": [
                            36,
                            40
                        ],
                        "static": false,
                        "computed": false,
                        "key": {
                            "type": "PrivateIdentifier",
                            "loc": {
                                "start": {
                                    "line": 4,
                                    "column": 4
                                },
                                "end": {
                                    "line": 4,
                                    "column": 8
                                }
                            },
                            "range": [
                                36,
                                40
                            ],
                            "name": "ccc"
                        },
                        "value": null
                    }
                ]
            }
        }
    ],
    "sourceType": "script",
    "tokens": [
        {
            "type": "Keyword",
            "value": "class",
            "loc": {
                "start": {
                    "line": 1,
                    "column": 0
                },
                "end": {
                    "line": 1,
                    "column": 5
                }
            },
            "range": [
                0,
                5
            ]
        },
        {
            "type": "Identifier",
            "value": "C",
            "loc": {
                "start": {
                    "line": 1,
                    "column": 6
                },
                "end": {
                    "line": 1,
                    "column": 7
                }
            },
            "range": [
                6,
                7
            ]
        },
        {
            "type": "Punctuator",
            "value": "{",
            "loc": {
                "start": {
                    "line": 1,
                    "column": 8
                },
                "end": {
                    "line": 1,
                    "column": 9
                }
            },
            "range": [
                8,
                9
            ]
        },
        {
            "type": "PrivateIdentifier",
            "value": "aaa",
            "loc": {
                "start": {
                    "line": 2,
                    "column": 4
                },
                "end": {
                    "line": 2,
                    "column": 8
                }
            },
            "range": [
                14,
                18
            ]
        },
        {
            "type": "PrivateIdentifier",
            "value": "bbb",
            "loc": {
                "start": {
                    "line": 3,
                    "column": 4
                },
                "end": {
                    "line": 3,
                    "column": 8
                }
            },
            "range": [
                23,
                27
            ]
        },
        {
            "type": "Punctuator",
            "value": "=",
            "loc": {
                "start": {
                    "line": 3,
                    "column": 9
                },
                "end": {
                    "line": 3,
                    "column": 10
                }
            },
            "range": [
                28,
                29
            ]
        },
        {
            "type": "Numeric",
            "value": "0",
            "loc": {
                "start": {
                    "line": 3,
                    "column": 11
                },
                "end": {
                    "line": 3,
                    "column": 12
                }
            },
            "range": [
                30,
                31
            ]
        },
        {
            "type": "PrivateIdentifier",
            "value": "ccc",
            "loc": {
                "start": {
                    "line": 4,
                    "column": 4
                },
                "end": {
                    "line": 4,
                    "column": 8
                }
            },
            "range": [
                36,
                40
            ]
        },
        {
            "type": "Punctuator",
            "value": "}",
            "loc": {
                "start": {
                    "line": 5,
                    "column": 0
                },
                "end": {
                    "line": 5,
                    "column": 1
                }
            },
            "range": [
                41,
                42
            ]
        }
    ]
};