export default {
    "type": "Program",
    "loc": {
        "start": {
            "line": 1,
            "column": 0
        },
        "end": {
            "line": 18,
            "column": 1
        }
    },
    "range": [
        0,
        247
    ],
    "body": [
        {
            "type": "ClassDeclaration",
            "loc": {
                "start": {
                    "line": 1,
                    "column": 0
                },
                "end": {
                    "line": 18,
                    "column": 1
                }
            },
            "range": [
                0,
                247
            ],
            "id": {
                "type": "Identifier",
                "loc": {
                    "start": {
                        "line": 1,
                        "column": 6
                    },
                    "end": {
                        "line": 1,
                        "column": 7
                    }
                },
                "range": [
                    6,
                    7
                ],
                "name": "C"
            },
            "superClass": null,
            "body": {
                "type": "ClassBody",
                "loc": {
                    "start": {
                        "line": 1,
                        "column": 8
                    },
                    "end": {
                        "line": 18,
                        "column": 1
                    }
                },
                "range": [
                    8,
                    247
                ],
                "body": [
                    {
                        "type": "PropertyDefinition",
                        "loc": {
                            "start": {
                                "line": 3,
                                "column": 4
                            },
                            "end": {
                                "line": 4,
                                "column": 9
                            }
                        },
                        "range": [
                            75,
                            91
                        ],
                        "static": true,
                        "computed": false,
                        "key": {
                            "type": "Identifier",
                            "loc": {
                                "start": {
                                    "line": 4,
                                    "column": 4
                                },
                                "end": {
                                    "line": 4,
                                    "column": 9
                                }
                            },
                            "range": [
                                86,
                                91
                            ],
                            "name": "async"
                        },
                        "value": null
                    },
                    {
                        "type": "MethodDefinition",
                        "loc": {
                            "start": {
                                "line": 5,
                                "column": 4
                            },
                            "end": {
                                "line": 5,
                                "column": 16
                            }
                        },
                        "range": [
                            96,
                            108
                        ],
                        "static": false,
                        "computed": false,
                        "key": {
                            "type": "PrivateIdentifier",
                            "loc": {
                                "start": {
                                    "line": 5,
                                    "column": 4
                                },
                                "end": {
                                    "line": 5,
                                    "column": 11
                                }
                            },
                            "range": [
                                96,
                                103
                            ],
                            "name": "method"
                        },
                        "kind": "method",
                        "value": {
                            "type": "FunctionExpression",
                            "loc": {
                                "start": {
                                    "line": 5,
                                    "column": 11
                                },
                                "end": {
                                    "line": 5,
                                    "column": 16
                                }
                            },
                            "range": [
                                103,
                                108
                            ],
                            "id": null,
                            "expression": false,
                            "generator": false,
                            "async": false,
                            "params": [],
                            "body": {
                                "type": "BlockStatement",
                                "loc": {
                                    "start": {
                                        "line": 5,
                                        "column": 14
                                    },
                                    "end": {
                                        "line": 5,
                                        "column": 16
                                    }
                                },
                                "range": [
                                    106,
                                    108
                                ],
                                "body": []
                            }
                        }
                    },
                    {
                        "type": "PropertyDefinition",
                        "loc": {
                            "start": {
                                "line": 7,
                                "column": 4
                            },
                            "end": {
                                "line": 8,
                                "column": 9
                            }
                        },
                        "range": [
                            118,
                            134
                        ],
                        "static": true,
                        "computed": false,
                        "key": {
                            "type": "Identifier",
                            "loc": {
                                "start": {
                                    "line": 8,
                                    "column": 4
                                },
                                "end": {
                                    "line": 8,
                                    "column": 9
                                }
                            },
                            "range": [
                                129,
                                134
                            ],
                            "name": "async"
                        },
                        "value": null
                    },
                    {
                        "type": "MethodDefinition",
                        "loc": {
                            "start": {
                                "line": 9,
                                "column": 4
                            },
                            "end": {
                                "line": 9,
                                "column": 21
                            }
                        },
                        "range": [
                            139,
                            156
                        ],
                        "static": false,
                        "computed": false,
                        "key": {
                            "type": "PrivateIdentifier",
                            "loc": {
                                "start": {
                                    "line": 9,
                                    "column": 6
                                },
                                "end": {
                                    "line": 9,
                                    "column": 16
                                }
                            },
                            "range": [
                                141,
                                151
                            ],
                            "name": "generator"
                        },
                        "kind": "method",
                        "value": {
                            "type": "FunctionExpression",
                            "loc": {
                                "start": {
                                    "line": 9,
                                    "column": 16
                                },
                                "end": {
                                    "line": 9,
                                    "column": 21
                                }
                            },
                            "range": [
                                151,
                                156
                            ],
                            "id": null,
                            "expression": false,
                            "generator": true,
                            "async": false,
                            "params": [],
                            "body": {
                                "type": "BlockStatement",
                                "loc": {
                                    "start": {
                                        "line": 9,
                                        "column": 19
                                    },
                                    "end": {
                                        "line": 9,
                                        "column": 21
                                    }
                                },
                                "range": [
                                    154,
                                    156
                                ],
                                "body": []
                            }
                        }
                    },
                    {
                        "type": "PropertyDefinition",
                        "loc": {
                            "start": {
                                "line": 11,
                                "column": 4
                            },
                            "end": {
                                "line": 12,
                                "column": 9
                            }
                        },
                        "range": [
                            166,
                            182
                        ],
                        "static": true,
                        "computed": false,
                        "key": {
                            "type": "Identifier",
                            "loc": {
                                "start": {
                                    "line": 12,
                                    "column": 4
                                },
                                "end": {
                                    "line": 12,
                                    "column": 9
                                }
                            },
                            "range": [
                                177,
                                182
                            ],
                            "name": "async"
                        },
                        "value": null
                    },
                    {
                        "type": "MethodDefinition",
                        "loc": {
                            "start": {
                                "line": 13,
                                "column": 4
                            },
                            "end": {
                                "line": 13,
                                "column": 15
                            }
                        },
                        "range": [
                            187,
                            198
                        ],
                        "static": false,
                        "computed": false,
                        "key": {
                            "type": "Identifier",
                            "loc": {
                                "start": {
                                    "line": 13,
                                    "column": 4
                                },
                                "end": {
                                    "line": 13,
                                    "column": 10
                                }
                            },
                            "range": [
                                187,
                                193
                            ],
                            "name": "method"
                        },
                        "kind": "method",
                        "value": {
                            "type": "FunctionExpression",
                            "loc": {
                                "start": {
                                    "line": 13,
                                    "column": 10
                                },
                                "end": {
                                    "line": 13,
                                    "column": 15
                                }
                            },
                            "range": [
                                193,
                                198
                            ],
                            "id": null,
                            "expression": false,
                            "generator": false,
                            "async": false,
                            "params": [],
                            "body": {
                                "type": "BlockStatement",
                                "loc": {
                                    "start": {
                                        "line": 13,
                                        "column": 13
                                    },
                                    "end": {
                                        "line": 13,
                                        "column": 15
                                    }
                                },
                                "range": [
                                    196,
                                    198
                                ],
                                "body": []
                            }
                        }
                    },
                    {
                        "type": "PropertyDefinition",
                        "loc": {
                            "start": {
                                "line": 15,
                                "column": 4
                            },
                            "end": {
                                "line": 16,
                                "column": 9
                            }
                        },
                        "range": [
                            208,
                            224
                        ],
                        "static": true,
                        "computed": false,
                        "key": {
                            "type": "Identifier",
                            "loc": {
                                "start": {
                                    "line": 16,
                                    "column": 4
                                },
                                "end": {
                                    "line": 16,
                                    "column": 9
                                }
                            },
                            "range": [
                                219,
                                224
                            ],
                            "name": "async"
                        },
                        "value": null
                    },
                    {
                        "type": "MethodDefinition",
                        "loc": {
                            "start": {
                                "line": 17,
                                "column": 4
                            },
                            "end": {
                                "line": 17,
                                "column": 20
                            }
                        },
                        "range": [
                            229,
                            245
                        ],
                        "static": false,
                        "computed": false,
                        "key": {
                            "type": "Identifier",
                            "loc": {
                                "start": {
                                    "line": 17,
                                    "column": 6
                                },
                                "end": {
                                    "line": 17,
                                    "column": 15
                                }
                            },
                            "range": [
                                231,
                                240
                            ],
                            "name": "generator"
                        },
                        "kind": "method",
                        "value": {
                            "type": "FunctionExpression",
                            "loc": {
                                "start": {
                                    "line": 17,
                                    "column": 15
                                },
                                "end": {
                                    "line": 17,
                                    "column": 20
                                }
                            },
                            "range": [
                                240,
                                245
                            ],
                            "id": null,
                            "expression": false,
                            "generator": true,
                            "async": false,
                            "params": [],
                            "body": {
                                "type": "BlockStatement",
                                "loc": {
                                    "start": {
                                        "line": 17,
                                        "column": 18
                                    },
                                    "end": {
                                        "line": 17,
                                        "column": 20
                                    }
                                },
                                "range": [
                                    243,
                                    245
                                ],
                                "body": []
                            }
                        }
                    }
                ]
            }
        }
    ],
    "sourceType": "script",
    "tokens": [
        {
            "type": "Keyword",
            "value": "class",
            "loc": {
                "start": {
                    "line": 1,
                    "column": 0
                },
                "end": {
                    "line": 1,
                    "column": 5
                }
            },
            "range": [
                0,
                5
            ]
        },
        {
            "type": "Identifier",
            "value": "C",
            "loc": {
                "start": {
                    "line": 1,
                    "column": 6
                },
                "end": {
                    "line": 1,
                    "column": 7
                }
            },
            "range": [
                6,
                7
            ]
        },
        {
            "type": "Punctuator",
            "value": "{",
            "loc": {
                "start": {
                    "line": 1,
                    "column": 8
                },
                "end": {
                    "line": 1,
                    "column": 9
                }
            },
            "range": [
                8,
                9
            ]
        },
        {
            "type": "Keyword",
            "value": "static",
            "loc": {
                "start": {
                    "line": 3,
                    "column": 4
                },
                "end": {
                    "line": 3,
                    "column": 10
                }
            },
            "range": [
                75,
                81
            ]
        },
        {
            "type": "Identifier",
            "value": "async",
            "loc": {
                "start": {
                    "line": 4,
                    "column": 4
                },
                "end": {
                    "line": 4,
                    "column": 9
                }
            },
            "range": [
                86,
                91
            ]
        },
        {
            "type": "PrivateIdentifier",
            "value": "method",
            "loc": {
                "start": {
                    "line": 5,
                    "column": 4
                },
                "end": {
                    "line": 5,
                    "column": 11
                }
            },
            "range": [
                96,
                103
            ]
        },
        {
            "type": "Punctuator",
            "value": "(",
            "loc": {
                "start": {
                    "line": 5,
                    "column": 11
                },
                "end": {
                    "line": 5,
                    "column": 12
                }
            },
            "range": [
                103,
                104
            ]
        },
        {
            "type": "Punctuator",
            "value": ")",
            "loc": {
                "start": {
                    "line": 5,
                    "column": 12
                },
                "end": {
                    "line": 5,
                    "column": 13
                }
            },
            "range": [
                104,
                105
            ]
        },
        {
            "type": "Punctuator",
            "value": "{",
            "loc": {
                "start": {
                    "line": 5,
                    "column": 14
                },
                "end": {
                    "line": 5,
                    "column": 15
                }
            },
            "range": [
                106,
                107
            ]
        },
        {
            "type": "Punctuator",
            "value": "}",
            "loc": {
                "start": {
                    "line": 5,
                    "column": 15
                },
                "end": {
                    "line": 5,
                    "column": 16
                }
            },
            "range": [
                107,
                108
            ]
        },
        {
            "type": "Keyword",
            "value": "static",
            "loc": {
                "start": {
                    "line": 7,
                    "column": 4
                },
                "end": {
                    "line": 7,
                    "column": 10
                }
            },
            "range": [
                118,
                124
            ]
        },
        {
            "type": "Identifier",
            "value": "async",
            "loc": {
                "start": {
                    "line": 8,
                    "column": 4
                },
                "end": {
                    "line": 8,
                    "column": 9
                }
            },
            "range": [
                129,
                134
            ]
        },
        {
            "type": "Punctuator",
            "value": "*",
            "loc": {
                "start": {
                    "line": 9,
                    "column": 4
                },
                "end": {
                    "line": 9,
                    "column": 5
                }
            },
            "range": [
                139,
                140
            ]
        },
        {
            "type": "PrivateIdentifier",
            "value": "generator",
            "loc": {
                "start": {
                    "line": 9,
                    "column": 6
                },
                "end": {
                    "line": 9,
                    "column": 16
                }
            },
            "range": [
                141,
                151
            ]
        },
        {
            "type": "Punctuator",
            "value": "(",
            "loc": {
                "start": {
                    "line": 9,
                    "column": 16
                },
                "end": {
                    "line": 9,
                    "column": 17
                }
            },
            "range": [
                151,
                152
            ]
        },
        {
            "type": "Punctuator",
            "value": ")",
            "loc": {
                "start": {
                    "line": 9,
                    "column": 17
                },
                "end": {
                    "line": 9,
                    "column": 18
                }
            },
            "range": [
                152,
                153
            ]
        },
        {
            "type": "Punctuator",
            "value": "{",
            "loc": {
                "start": {
                    "line": 9,
                    "column": 19
                },
                "end": {
                    "line": 9,
                    "column": 20
                }
            },
            "range": [
                154,
                155
            ]
        },
        {
            "type": "Punctuator",
            "value": "}",
            "loc": {
                "start": {
                    "line": 9,
                    "column": 20
                },
                "end": {
                    "line": 9,
                    "column": 21
                }
            },
            "range": [
                155,
                156
            ]
        },
        {
            "type": "Keyword",
            "value": "static",
            "loc": {
                "start": {
                    "line": 11,
                    "column": 4
                },
                "end": {
                    "line": 11,
                    "column": 10
                }
            },
            "range": [
                166,
                172
            ]
        },
        {
            "type": "Identifier",
            "value": "async",
            "loc": {
                "start": {
                    "line": 12,
                    "column": 4
                },
                "end": {
                    "line": 12,
                    "column": 9
                }
            },
            "range": [
                177,
                182
            ]
        },
        {
            "type": "Identifier",
            "value": "method",
            "loc": {
                "start": {
                    "line": 13,
                    "column": 4
                },
                "end": {
                    "line": 13,
                    "column": 10
                }
            },
            "range": [
                187,
                193
            ]
        },
        {
            "type": "Punctuator",
            "value": "(",
            "loc": {
                "start": {
                    "line": 13,
                    "column": 10
                },
                "end": {
                    "line": 13,
                    "column": 11
                }
            },
            "range": [
                193,
                194
            ]
        },
        {
            "type": "Punctuator",
            "value": ")",
            "loc": {
                "start": {
                    "line": 13,
                    "column": 11
                },
                "end": {
                    "line": 13,
                    "column": 12
                }
            },
            "range": [
                194,
                195
            ]
        },
        {
            "type": "Punctuator",
            "value": "{",
            "loc": {
                "start": {
                    "line": 13,
                    "column": 13
                },
                "end": {
                    "line": 13,
                    "column": 14
                }
            },
            "range": [
                196,
                197
            ]
        },
        {
            "type": "Punctuator",
            "value": "}",
            "loc": {
                "start": {
                    "line": 13,
                    "column": 14
                },
                "end": {
                    "line": 13,
                    "column": 15
                }
            },
            "range": [
                197,
                198
            ]
        },
        {
            "type": "Keyword",
            "value": "static",
            "loc": {
                "start": {
                    "line": 15,
                    "column": 4
                },
                "end": {
                    "line": 15,
                    "column": 10
                }
            },
            "range": [
                208,
                214
            ]
        },
        {
            "type": "Identifier",
            "value": "async",
            "loc": {
                "start": {
                    "line": 16,
                    "column": 4
                },
                "end": {
                    "line": 16,
                    "column": 9
                }
            },
            "range": [
                219,
                224
            ]
        },
        {
            "type": "Punctuator",
            "value": "*",
            "loc": {
                "start": {
                    "line": 17,
                    "column": 4
                },
                "end": {
                    "line": 17,
                    "column": 5
                }
            },
            "range": [
                229,
                230
            ]
        },
        {
            "type": "Identifier",
            "value": "generator",
            "loc": {
                "start": {
                    "line": 17,
                    "column": 6
                },
                "end": {
                    "line": 17,
                    "column": 15
                }
            },
            "range": [
                231,
                240
            ]
        },
        {
            "type": "Punctuator",
            "value": "(",
            "loc": {
                "start": {
                    "line": 17,
                    "column": 15
                },
                "end": {
                    "line": 17,
                    "column": 16
                }
            },
            "range": [
                240,
                241
            ]
        },
        {
            "type": "Punctuator",
            "value": ")",
            "loc": {
                "start": {
                    "line": 17,
                    "column": 16
                },
                "end": {
                    "line": 17,
                    "column": 17
                }
            },
            "range": [
                241,
                242
            ]
        },
        {
            "type": "Punctuator",
            "value": "{",
            "loc": {
                "start": {
                    "line": 17,
                    "column": 18
                },
                "end": {
                    "line": 17,
                    "column": 19
                }
            },
            "range": [
                243,
                244
            ]
        },
        {
            "type": "Punctuator",
            "value": "}",
            "loc": {
                "start": {
                    "line": 17,
                    "column": 19
                },
                "end": {
                    "line": 17,
                    "column": 20
                }
            },
            "range": [
                244,
                245
            ]
        },
        {
            "type": "Punctuator",
            "value": "}",
            "loc": {
                "start": {
                    "line": 18,
                    "column": 0
                },
                "end": {
                    "line": 18,
                    "column": 1
                }
            },
            "range": [
                246,
                247
            ]
        }
    ]
};