export default {
    "type": "Program",
    "loc": {
        "start": {
            "line": 1,
            "column": 0
        },
        "end": {
            "line": 6,
            "column": 1
        }
    },
    "range": [
        0,
        51
    ],
    "body": [
        {
            "type": "ClassDeclaration",
            "loc": {
                "start": {
                    "line": 1,
                    "column": 0
                },
                "end": {
                    "line": 6,
                    "column": 1
                }
            },
            "range": [
                0,
                51
            ],
            "id": {
                "type": "Identifier",
                "loc": {
                    "start": {
                        "line": 1,
                        "column": 6
                    },
                    "end": {
                        "line": 1,
                        "column": 7
                    }
                },
                "range": [
                    6,
                    7
                ],
                "name": "C"
            },
            "superClass": null,
            "body": {
                "type": "ClassBody",
                "loc": {
                    "start": {
                        "line": 1,
                        "column": 8
                    },
                    "end": {
                        "line": 6,
                        "column": 1
                    }
                },
                "range": [
                    8,
                    51
                ],
                "body": [
                    {
                        "type": "PropertyDefinition",
                        "loc": {
                            "start": {
                                "line": 2,
                                "column": 4
                            },
                            "end": {
                                "line": 2,
                                "column": 7
                            }
                        },
                        "range": [
                            14,
                            17
                        ],
                        "static": false,
                        "computed": false,
                        "key": {
                            "type": "PrivateIdentifier",
                            "loc": {
                                "start": {
                                    "line": 2,
                                    "column": 4
                                },
                                "end": {
                                    "line": 2,
                                    "column": 6
                                }
                            },
                            "range": [
                                14,
                                16
                            ],
                            "name": "a"
                        },
                        "value": null
                    },
                    {
                        "type": "MethodDefinition",
                        "loc": {
                            "start": {
                                "line": 3,
                                "column": 4
                            },
                            "end": {
                                "line": 5,
                                "column": 5
                            }
                        },
                        "range": [
                            22,
                            49
                        ],
                        "static": false,
                        "computed": false,
                        "key": {
                            "type": "Identifier",
                            "loc": {
                                "start": {
                                    "line": 3,
                                    "column": 4
                                },
                                "end": {
                                    "line": 3,
                                    "column": 5
                                }
                            },
                            "range": [
                                22,
                                23
                            ],
                            "name": "f"
                        },
                        "kind": "method",
                        "value": {
                            "type": "FunctionExpression",
                            "loc": {
                                "start": {
                                    "line": 3,
                                    "column": 5
                                },
                                "end": {
                                    "line": 5,
                                    "column": 5
                                }
                            },
                            "range": [
                                23,
                                49
                            ],
                            "id": null,
                            "expression": false,
                            "generator": false,
                            "async": false,
                            "params": [],
                            "body": {
                                "type": "BlockStatement",
                                "loc": {
                                    "start": {
                                        "line": 3,
                                        "column": 8
                                    },
                                    "end": {
                                        "line": 5,
                                        "column": 5
                                    }
                                },
                                "range": [
                                    26,
                                    49
                                ],
                                "body": [
                                    {
                                        "type": "ExpressionStatement",
                                        "loc": {
                                            "start": {
                                                "line": 4,
                                                "column": 8
                                            },
                                            "end": {
                                                "line": 4,
                                                "column": 15
                                            }
                                        },
                                        "range": [
                                            36,
                                            43
                                        ],
                                        "expression": {
                                            "type": "MemberExpression",
                                            "loc": {
                                                "start": {
                                                    "line": 4,
                                                    "column": 8
                                                },
                                                "end": {
                                                    "line": 4,
                                                    "column": 15
                                                }
                                            },
                                            "range": [
                                                36,
                                                43
                                            ],
                                            "object": {
                                                "type": "ThisExpression",
                                                "loc": {
                                                    "start": {
                                                        "line": 4,
                                                        "column": 8
                                                    },
                                                    "end": {
                                                        "line": 4,
                                                        "column": 12
                                                    }
                                                },
                                                "range": [
                                                    36,
                                                    40
                                                ]
                                            },
                                            "property": {
                                                "type": "PrivateIdentifier",
                                                "loc": {
                                                    "start": {
                                                        "line": 4,
                                                        "column": 13
                                                    },
                                                    "end": {
                                                        "line": 4,
                                                        "column": 15
                                                    }
                                                },
                                                "range": [
                                                    41,
                                                    43
                                                ],
                                                "name": "a"
                                            },
                                            "computed": false,
                                            "optional": false
                                        }
                                    }
                                ]
                            }
                        }
                    }
                ]
            }
        }
    ],
    "sourceType": "script",
    "tokens": [
        {
            "type": "Keyword",
            "value": "class",
            "loc": {
                "start": {
                    "line": 1,
                    "column": 0
                },
                "end": {
                    "line": 1,
                    "column": 5
                }
            },
            "range": [
                0,
                5
            ]
        },
        {
            "type": "Identifier",
            "value": "C",
            "loc": {
                "start": {
                    "line": 1,
                    "column": 6
                },
                "end": {
                    "line": 1,
                    "column": 7
                }
            },
            "range": [
                6,
                7
            ]
        },
        {
            "type": "Punctuator",
            "value": "{",
            "loc": {
                "start": {
                    "line": 1,
                    "column": 8
                },
                "end": {
                    "line": 1,
                    "column": 9
                }
            },
            "range": [
                8,
                9
            ]
        },
        {
            "type": "PrivateIdentifier",
            "value": "a",
            "loc": {
                "start": {
                    "line": 2,
                    "column": 4
                },
                "end": {
                    "line": 2,
                    "column": 6
                }
            },
            "range": [
                14,
                16
            ]
        },
        {
            "type": "Punctuator",
            "value": ";",
            "loc": {
                "start": {
                    "line": 2,
                    "column": 6
                },
                "end": {
                    "line": 2,
                    "column": 7
                }
            },
            "range": [
                16,
                17
            ]
        },
        {
            "type": "Identifier",
            "value": "f",
            "loc": {
                "start": {
                    "line": 3,
                    "column": 4
                },
                "end": {
                    "line": 3,
                    "column": 5
                }
            },
            "range": [
                22,
                23
            ]
        },
        {
            "type": "Punctuator",
            "value": "(",
            "loc": {
                "start": {
                    "line": 3,
                    "column": 5
                },
                "end": {
                    "line": 3,
                    "column": 6
                }
            },
            "range": [
                23,
                24
            ]
        },
        {
            "type": "Punctuator",
            "value": ")",
            "loc": {
                "start": {
                    "line": 3,
                    "column": 6
                },
                "end": {
                    "line": 3,
                    "column": 7
                }
            },
            "range": [
                24,
                25
            ]
        },
        {
            "type": "Punctuator",
            "value": "{",
            "loc": {
                "start": {
                    "line": 3,
                    "column": 8
                },
                "end": {
                    "line": 3,
                    "column": 9
                }
            },
            "range": [
                26,
                27
            ]
        },
        {
            "type": "Keyword",
            "value": "this",
            "loc": {
                "start": {
                    "line": 4,
                    "column": 8
                },
                "end": {
                    "line": 4,
                    "column": 12
                }
            },
            "range": [
                36,
                40
            ]
        },
        {
            "type": "Punctuator",
            "value": ".",
            "loc": {
                "start": {
                    "line": 4,
                    "column": 12
                },
                "end": {
                    "line": 4,
                    "column": 13
                }
            },
            "range": [
                40,
                41
            ]
        },
        {
            "type": "PrivateIdentifier",
            "value": "a",
            "loc": {
                "start": {
                    "line": 4,
                    "column": 13
                },
                "end": {
                    "line": 4,
                    "column": 15
                }
            },
            "range": [
                41,
                43
            ]
        },
        {
            "type": "Punctuator",
            "value": "}",
            "loc": {
                "start": {
                    "line": 5,
                    "column": 4
                },
                "end": {
                    "line": 5,
                    "column": 5
                }
            },
            "range": [
                48,
                49
            ]
        },
        {
            "type": "Punctuator",
            "value": "}",
            "loc": {
                "start": {
                    "line": 6,
                    "column": 0
                },
                "end": {
                    "line": 6,
                    "column": 1
                }
            },
            "range": [
                50,
                51
            ]
        }
    ]
};