export default {
    "type": "Program",
    "loc": {
        "start": {
            "line": 1,
            "column": 0
        },
        "end": {
            "line": 6,
            "column": 1
        }
    },
    "range": [
        0,
        104
    ],
    "body": [
        {
            "type": "ClassDeclaration",
            "loc": {
                "start": {
                    "line": 1,
                    "column": 0
                },
                "end": {
                    "line": 6,
                    "column": 1
                }
            },
            "range": [
                0,
                104
            ],
            "id": {
                "type": "Identifier",
                "loc": {
                    "start": {
                        "line": 1,
                        "column": 6
                    },
                    "end": {
                        "line": 1,
                        "column": 7
                    }
                },
                "range": [
                    6,
                    7
                ],
                "name": "C"
            },
            "superClass": null,
            "body": {
                "type": "ClassBody",
                "loc": {
                    "start": {
                        "line": 1,
                        "column": 8
                    },
                    "end": {
                        "line": 6,
                        "column": 1
                    }
                },
                "range": [
                    8,
                    104
                ],
                "body": [
                    {
                        "type": "MethodDefinition",
                        "loc": {
                            "start": {
                                "line": 2,
                                "column": 4
                            },
                            "end": {
                                "line": 2,
                                "column": 16
                            }
                        },
                        "range": [
                            14,
                            26
                        ],
                        "static": false,
                        "computed": false,
                        "key": {
                            "type": "PrivateIdentifier",
                            "loc": {
                                "start": {
                                    "line": 2,
                                    "column": 4
                                },
                                "end": {
                                    "line": 2,
                                    "column": 11
                                }
                            },
                            "range": [
                                14,
                                21
                            ],
                            "name": "normal"
                        },
                        "kind": "method",
                        "value": {
                            "type": "FunctionExpression",
                            "loc": {
                                "start": {
                                    "line": 2,
                                    "column": 11
                                },
                                "end": {
                                    "line": 2,
                                    "column": 16
                                }
                            },
                            "range": [
                                21,
                                26
                            ],
                            "id": null,
                            "expression": false,
                            "generator": false,
                            "async": false,
                            "params": [],
                            "body": {
                                "type": "BlockStatement",
                                "loc": {
                                    "start": {
                                        "line": 2,
                                        "column": 14
                                    },
                                    "end": {
                                        "line": 2,
                                        "column": 16
                                    }
                                },
                                "range": [
                                    24,
                                    26
                                ],
                                "body": []
                            }
                        }
                    },
                    {
                        "type": "MethodDefinition",
                        "loc": {
                            "start": {
                                "line": 3,
                                "column": 4
                            },
                            "end": {
                                "line": 3,
                                "column": 21
                            }
                        },
                        "range": [
                            31,
                            48
                        ],
                        "static": false,
                        "computed": false,
                        "key": {
                            "type": "PrivateIdentifier",
                            "loc": {
                                "start": {
                                    "line": 3,
                                    "column": 10
                                },
                                "end": {
                                    "line": 3,
                                    "column": 16
                                }
                            },
                            "range": [
                                37,
                                43
                            ],
                            "name": "async"
                        },
                        "kind": "method",
                        "value": {
                            "type": "FunctionExpression",
                            "loc": {
                                "start": {
                                    "line": 3,
                                    "column": 16
                                },
                                "end": {
                                    "line": 3,
                                    "column": 21
                                }
                            },
                            "range": [
                                43,
                                48
                            ],
                            "id": null,
                            "expression": false,
                            "generator": false,
                            "async": true,
                            "params": [],
                            "body": {
                                "type": "BlockStatement",
                                "loc": {
                                    "start": {
                                        "line": 3,
                                        "column": 19
                                    },
                                    "end": {
                                        "line": 3,
                                        "column": 21
                                    }
                                },
                                "range": [
                                    46,
                                    48
                                ],
                                "body": []
                            }
                        }
                    },
                    {
                        "type": "MethodDefinition",
                        "loc": {
                            "start": {
                                "line": 4,
                                "column": 4
                            },
                            "end": {
                                "line": 4,
                                "column": 21
                            }
                        },
                        "range": [
                            53,
                            70
                        ],
                        "static": false,
                        "computed": false,
                        "key": {
                            "type": "PrivateIdentifier",
                            "loc": {
                                "start": {
                                    "line": 4,
                                    "column": 6
                                },
                                "end": {
                                    "line": 4,
                                    "column": 16
                                }
                            },
                            "range": [
                                55,
                                65
                            ],
                            "name": "generator"
                        },
                        "kind": "method",
                        "value": {
                            "type": "FunctionExpression",
                            "loc": {
                                "start": {
                                    "line": 4,
                                    "column": 16
                                },
                                "end": {
                                    "line": 4,
                                    "column": 21
                                }
                            },
                            "range": [
                                65,
                                70
                            ],
                            "id": null,
                            "expression": false,
                            "generator": true,
                            "async": false,
                            "params": [],
                            "body": {
                                "type": "BlockStatement",
                                "loc": {
                                    "start": {
                                        "line": 4,
                                        "column": 19
                                    },
                                    "end": {
                                        "line": 4,
                                        "column": 21
                                    }
                                },
                                "range": [
                                    68,
                                    70
                                ],
                                "body": []
                            }
                        }
                    },
                    {
                        "type": "MethodDefinition",
                        "loc": {
                            "start": {
                                "line": 5,
                                "column": 4
                            },
                            "end": {
                                "line": 5,
                                "column": 31
                            }
                        },
                        "range": [
                            75,
                            102
                        ],
                        "static": false,
                        "computed": false,
                        "key": {
                            "type": "PrivateIdentifier",
                            "loc": {
                                "start": {
                                    "line": 5,
                                    "column": 11
                                },
                                "end": {
                                    "line": 5,
                                    "column": 26
                                }
                            },
                            "range": [
                                82,
                                97
                            ],
                            "name": "asyncGenerator"
                        },
                        "kind": "method",
                        "value": {
                            "type": "FunctionExpression",
                            "loc": {
                                "start": {
                                    "line": 5,
                                    "column": 26
                                },
                                "end": {
                                    "line": 5,
                                    "column": 31
                                }
                            },
                            "range": [
                                97,
                                102
                            ],
                            "id": null,
                            "expression": false,
                            "generator": true,
                            "async": true,
                            "params": [],
                            "body": {
                                "type": "BlockStatement",
                                "loc": {
                                    "start": {
                                        "line": 5,
                                        "column": 29
                                    },
                                    "end": {
                                        "line": 5,
                                        "column": 31
                                    }
                                },
                                "range": [
                                    100,
                                    102
                                ],
                                "body": []
                            }
                        }
                    }
                ]
            }
        }
    ],
    "sourceType": "script",
    "tokens": [
        {
            "type": "Keyword",
            "value": "class",
            "loc": {
                "start": {
                    "line": 1,
                    "column": 0
                },
                "end": {
                    "line": 1,
                    "column": 5
                }
            },
            "range": [
                0,
                5
            ]
        },
        {
            "type": "Identifier",
            "value": "C",
            "loc": {
                "start": {
                    "line": 1,
                    "column": 6
                },
                "end": {
                    "line": 1,
                    "column": 7
                }
            },
            "range": [
                6,
                7
            ]
        },
        {
            "type": "Punctuator",
            "value": "{",
            "loc": {
                "start": {
                    "line": 1,
                    "column": 8
                },
                "end": {
                    "line": 1,
                    "column": 9
                }
            },
            "range": [
                8,
                9
            ]
        },
        {
            "type": "PrivateIdentifier",
            "value": "normal",
            "loc": {
                "start": {
                    "line": 2,
                    "column": 4
                },
                "end": {
                    "line": 2,
                    "column": 11
                }
            },
            "range": [
                14,
                21
            ]
        },
        {
            "type": "Punctuator",
            "value": "(",
            "loc": {
                "start": {
                    "line": 2,
                    "column": 11
                },
                "end": {
                    "line": 2,
                    "column": 12
                }
            },
            "range": [
                21,
                22
            ]
        },
        {
            "type": "Punctuator",
            "value": ")",
            "loc": {
                "start": {
                    "line": 2,
                    "column": 12
                },
                "end": {
                    "line": 2,
                    "column": 13
                }
            },
            "range": [
                22,
                23
            ]
        },
        {
            "type": "Punctuator",
            "value": "{",
            "loc": {
                "start": {
                    "line": 2,
                    "column": 14
                },
                "end": {
                    "line": 2,
                    "column": 15
                }
            },
            "range": [
                24,
                25
            ]
        },
        {
            "type": "Punctuator",
            "value": "}",
            "loc": {
                "start": {
                    "line": 2,
                    "column": 15
                },
                "end": {
                    "line": 2,
                    "column": 16
                }
            },
            "range": [
                25,
                26
            ]
        },
        {
            "type": "Identifier",
            "value": "async",
            "loc": {
                "start": {
                    "line": 3,
                    "column": 4
                },
                "end": {
                    "line": 3,
                    "column": 9
                }
            },
            "range": [
                31,
                36
            ]
        },
        {
            "type": "PrivateIdentifier",
            "value": "async",
            "loc": {
                "start": {
                    "line": 3,
                    "column": 10
                },
                "end": {
                    "line": 3,
                    "column": 16
                }
            },
            "range": [
                37,
                43
            ]
        },
        {
            "type": "Punctuator",
            "value": "(",
            "loc": {
                "start": {
                    "line": 3,
                    "column": 16
                },
                "end": {
                    "line": 3,
                    "column": 17
                }
            },
            "range": [
                43,
                44
            ]
        },
        {
            "type": "Punctuator",
            "value": ")",
            "loc": {
                "start": {
                    "line": 3,
                    "column": 17
                },
                "end": {
                    "line": 3,
                    "column": 18
                }
            },
            "range": [
                44,
                45
            ]
        },
        {
            "type": "Punctuator",
            "value": "{",
            "loc": {
                "start": {
                    "line": 3,
                    "column": 19
                },
                "end": {
                    "line": 3,
                    "column": 20
                }
            },
            "range": [
                46,
                47
            ]
        },
        {
            "type": "Punctuator",
            "value": "}",
            "loc": {
                "start": {
                    "line": 3,
                    "column": 20
                },
                "end": {
                    "line": 3,
                    "column": 21
                }
            },
            "range": [
                47,
                48
            ]
        },
        {
            "type": "Punctuator",
            "value": "*",
            "loc": {
                "start": {
                    "line": 4,
                    "column": 4
                },
                "end": {
                    "line": 4,
                    "column": 5
                }
            },
            "range": [
                53,
                54
            ]
        },
        {
            "type": "PrivateIdentifier",
            "value": "generator",
            "loc": {
                "start": {
                    "line": 4,
                    "column": 6
                },
                "end": {
                    "line": 4,
                    "column": 16
                }
            },
            "range": [
                55,
                65
            ]
        },
        {
            "type": "Punctuator",
            "value": "(",
            "loc": {
                "start": {
                    "line": 4,
                    "column": 16
                },
                "end": {
                    "line": 4,
                    "column": 17
                }
            },
            "range": [
                65,
                66
            ]
        },
        {
            "type": "Punctuator",
            "value": ")",
            "loc": {
                "start": {
                    "line": 4,
                    "column": 17
                },
                "end": {
                    "line": 4,
                    "column": 18
                }
            },
            "range": [
                66,
                67
            ]
        },
        {
            "type": "Punctuator",
            "value": "{",
            "loc": {
                "start": {
                    "line": 4,
                    "column": 19
                },
                "end": {
                    "line": 4,
                    "column": 20
                }
            },
            "range": [
                68,
                69
            ]
        },
        {
            "type": "Punctuator",
            "value": "}",
            "loc": {
                "start": {
                    "line": 4,
                    "column": 20
                },
                "end": {
                    "line": 4,
                    "column": 21
                }
            },
            "range": [
                69,
                70
            ]
        },
        {
            "type": "Identifier",
            "value": "async",
            "loc": {
                "start": {
                    "line": 5,
                    "column": 4
                },
                "end": {
                    "line": 5,
                    "column": 9
                }
            },
            "range": [
                75,
                80
            ]
        },
        {
            "type": "Punctuator",
            "value": "*",
            "loc": {
                "start": {
                    "line": 5,
                    "column": 9
                },
                "end": {
                    "line": 5,
                    "column": 10
                }
            },
            "range": [
                80,
                81
            ]
        },
        {
            "type": "PrivateIdentifier",
            "value": "asyncGenerator",
            "loc": {
                "start": {
                    "line": 5,
                    "column": 11
                },
                "end": {
                    "line": 5,
                    "column": 26
                }
            },
            "range": [
                82,
                97
            ]
        },
        {
            "type": "Punctuator",
            "value": "(",
            "loc": {
                "start": {
                    "line": 5,
                    "column": 26
                },
                "end": {
                    "line": 5,
                    "column": 27
                }
            },
            "range": [
                97,
                98
            ]
        },
        {
            "type": "Punctuator",
            "value": ")",
            "loc": {
                "start": {
                    "line": 5,
                    "column": 27
                },
                "end": {
                    "line": 5,
                    "column": 28
                }
            },
            "range": [
                98,
                99
            ]
        },
        {
            "type": "Punctuator",
            "value": "{",
            "loc": {
                "start": {
                    "line": 5,
                    "column": 29
                },
                "end": {
                    "line": 5,
                    "column": 30
                }
            },
            "range": [
                100,
                101
            ]
        },
        {
            "type": "Punctuator",
            "value": "}",
            "loc": {
                "start": {
                    "line": 5,
                    "column": 30
                },
                "end": {
                    "line": 5,
                    "column": 31
                }
            },
            "range": [
                101,
                102
            ]
        },
        {
            "type": "Punctuator",
            "value": "}",
            "loc": {
                "start": {
                    "line": 6,
                    "column": 0
                },
                "end": {
                    "line": 6,
                    "column": 1
                }
            },
            "range": [
                103,
                104
            ]
        }
    ]
};