export default {
    "type": "Program",
    "loc": {
        "start": {
            "line": 1,
            "column": 0
        },
        "end": {
            "line": 11,
            "column": 1
        }
    },
    "range": [
        0,
        142
    ],
    "body": [
        {
            "type": "ClassDeclaration",
            "loc": {
                "start": {
                    "line": 1,
                    "column": 0
                },
                "end": {
                    "line": 11,
                    "column": 1
                }
            },
            "range": [
                0,
                142
            ],
            "id": {
                "type": "Identifier",
                "loc": {
                    "start": {
                        "line": 1,
                        "column": 6
                    },
                    "end": {
                        "line": 1,
                        "column": 7
                    }
                },
                "range": [
                    6,
                    7
                ],
                "name": "C"
            },
            "superClass": null,
            "body": {
                "type": "ClassBody",
                "loc": {
                    "start": {
                        "line": 1,
                        "column": 8
                    },
                    "end": {
                        "line": 11,
                        "column": 1
                    }
                },
                "range": [
                    8,
                    142
                ],
                "body": [
                    {
                        "type": "MethodDefinition",
                        "loc": {
                            "start": {
                                "line": 3,
                                "column": 4
                            },
                            "end": {
                                "line": 4,
                                "column": 15
                            }
                        },
                        "range": [
                            59,
                            78
                        ],
                        "static": false,
                        "computed": false,
                        "key": {
                            "type": "PrivateIdentifier",
                            "loc": {
                                "start": {
                                    "line": 4,
                                    "column": 4
                                },
                                "end": {
                                    "line": 4,
                                    "column": 11
                                }
                            },
                            "range": [
                                67,
                                74
                            ],
                            "name": "getter"
                        },
                        "kind": "get",
                        "value": {
                            "type": "FunctionExpression",
                            "loc": {
                                "start": {
                                    "line": 4,
                                    "column": 11
                                },
                                "end": {
                                    "line": 4,
                                    "column": 15
                                }
                            },
                            "range": [
                                74,
                                78
                            ],
                            "id": null,
                            "expression": false,
                            "generator": false,
                            "async": false,
                            "params": [],
                            "body": {
                                "type": "BlockStatement",
                                "loc": {
                                    "start": {
                                        "line": 4,
                                        "column": 13
                                    },
                                    "end": {
                                        "line": 4,
                                        "column": 15
                                    }
                                },
                                "range": [
                                    76,
                                    78
                                ],
                                "body": []
                            }
                        }
                    },
                    {
                        "type": "MethodDefinition",
                        "loc": {
                            "start": {
                                "line": 6,
                                "column": 4
                            },
                            "end": {
                                "line": 7,
                                "column": 16
                            }
                        },
                        "range": [
                            84,
                            104
                        ],
                        "static": false,
                        "computed": false,
                        "key": {
                            "type": "PrivateIdentifier",
                            "loc": {
                                "start": {
                                    "line": 7,
                                    "column": 4
                                },
                                "end": {
                                    "line": 7,
                                    "column": 11
                                }
                            },
                            "range": [
                                92,
                                99
                            ],
                            "name": "setter"
                        },
                        "kind": "set",
                        "value": {
                            "type": "FunctionExpression",
                            "loc": {
                                "start": {
                                    "line": 7,
                                    "column": 11
                                },
                                "end": {
                                    "line": 7,
                                    "column": 16
                                }
                            },
                            "range": [
                                99,
                                104
                            ],
                            "id": null,
                            "expression": false,
                            "generator": false,
                            "async": false,
                            "params": [
                                {
                                    "type": "Identifier",
                                    "loc": {
                                        "start": {
                                            "line": 7,
                                            "column": 12
                                        },
                                        "end": {
                                            "line": 7,
                                            "column": 13
                                        }
                                    },
                                    "range": [
                                        100,
                                        101
                                    ],
                                    "name": "x"
                                }
                            ],
                            "body": {
                                "type": "BlockStatement",
                                "loc": {
                                    "start": {
                                        "line": 7,
                                        "column": 14
                                    },
                                    "end": {
                                        "line": 7,
                                        "column": 16
                                    }
                                },
                                "range": [
                                    102,
                                    104
                                ],
                                "body": []
                            }
                        }
                    },
                    {
                        "type": "MethodDefinition",
                        "loc": {
                            "start": {
                                "line": 9,
                                "column": 4
                            },
                            "end": {
                                "line": 10,
                                "column": 23
                            }
                        },
                        "range": [
                            110,
                            140
                        ],
                        "static": false,
                        "computed": false,
                        "key": {
                            "type": "PrivateIdentifier",
                            "loc": {
                                "start": {
                                    "line": 10,
                                    "column": 4
                                },
                                "end": {
                                    "line": 10,
                                    "column": 19
                                }
                            },
                            "range": [
                                121,
                                136
                            ],
                            "name": "asyncGenerator"
                        },
                        "kind": "method",
                        "value": {
                            "type": "FunctionExpression",
                            "loc": {
                                "start": {
                                    "line": 10,
                                    "column": 19
                                },
                                "end": {
                                    "line": 10,
                                    "column": 23
                                }
                            },
                            "range": [
                                136,
                                140
                            ],
                            "id": null,
                            "expression": false,
                            "generator": true,
                            "async": true,
                            "params": [],
                            "body": {
                                "type": "BlockStatement",
                                "loc": {
                                    "start": {
                                        "line": 10,
                                        "column": 21
                                    },
                                    "end": {
                                        "line": 10,
                                        "column": 23
                                    }
                                },
                                "range": [
                                    138,
                                    140
                                ],
                                "body": []
                            }
                        }
                    }
                ]
            }
        }
    ],
    "sourceType": "script",
    "tokens": [
        {
            "type": "Keyword",
            "value": "class",
            "loc": {
                "start": {
                    "line": 1,
                    "column": 0
                },
                "end": {
                    "line": 1,
                    "column": 5
                }
            },
            "range": [
                0,
                5
            ]
        },
        {
            "type": "Identifier",
            "value": "C",
            "loc": {
                "start": {
                    "line": 1,
                    "column": 6
                },
                "end": {
                    "line": 1,
                    "column": 7
                }
            },
            "range": [
                6,
                7
            ]
        },
        {
            "type": "Punctuator",
            "value": "{",
            "loc": {
                "start": {
                    "line": 1,
                    "column": 8
                },
                "end": {
                    "line": 1,
                    "column": 9
                }
            },
            "range": [
                8,
                9
            ]
        },
        {
            "type": "Identifier",
            "value": "get",
            "loc": {
                "start": {
                    "line": 3,
                    "column": 4
                },
                "end": {
                    "line": 3,
                    "column": 7
                }
            },
            "range": [
                59,
                62
            ]
        },
        {
            "type": "PrivateIdentifier",
            "value": "getter",
            "loc": {
                "start": {
                    "line": 4,
                    "column": 4
                },
                "end": {
                    "line": 4,
                    "column": 11
                }
            },
            "range": [
                67,
                74
            ]
        },
        {
            "type": "Punctuator",
            "value": "(",
            "loc": {
                "start": {
                    "line": 4,
                    "column": 11
                },
                "end": {
                    "line": 4,
                    "column": 12
                }
            },
            "range": [
                74,
                75
            ]
        },
        {
            "type": "Punctuator",
            "value": ")",
            "loc": {
                "start": {
                    "line": 4,
                    "column": 12
                },
                "end": {
                    "line": 4,
                    "column": 13
                }
            },
            "range": [
                75,
                76
            ]
        },
        {
            "type": "Punctuator",
            "value": "{",
            "loc": {
                "start": {
                    "line": 4,
                    "column": 13
                },
                "end": {
                    "line": 4,
                    "column": 14
                }
            },
            "range": [
                76,
                77
            ]
        },
        {
            "type": "Punctuator",
            "value": "}",
            "loc": {
                "start": {
                    "line": 4,
                    "column": 14
                },
                "end": {
                    "line": 4,
                    "column": 15
                }
            },
            "range": [
                77,
                78
            ]
        },
        {
            "type": "Identifier",
            "value": "set",
            "loc": {
                "start": {
                    "line": 6,
                    "column": 4
                },
                "end": {
                    "line": 6,
                    "column": 7
                }
            },
            "range": [
                84,
                87
            ]
        },
        {
            "type": "PrivateIdentifier",
            "value": "setter",
            "loc": {
                "start": {
                    "line": 7,
                    "column": 4
                },
                "end": {
                    "line": 7,
                    "column": 11
                }
            },
            "range": [
                92,
                99
            ]
        },
        {
            "type": "Punctuator",
            "value": "(",
            "loc": {
                "start": {
                    "line": 7,
                    "column": 11
                },
                "end": {
                    "line": 7,
                    "column": 12
                }
            },
            "range": [
                99,
                100
            ]
        },
        {
            "type": "Identifier",
            "value": "x",
            "loc": {
                "start": {
                    "line": 7,
                    "column": 12
                },
                "end": {
                    "line": 7,
                    "column": 13
                }
            },
            "range": [
                100,
                101
            ]
        },
        {
            "type": "Punctuator",
            "value": ")",
            "loc": {
                "start": {
                    "line": 7,
                    "column": 13
                },
                "end": {
                    "line": 7,
                    "column": 14
                }
            },
            "range": [
                101,
                102
            ]
        },
        {
            "type": "Punctuator",
            "value": "{",
            "loc": {
                "start": {
                    "line": 7,
                    "column": 14
                },
                "end": {
                    "line": 7,
                    "column": 15
                }
            },
            "range": [
                102,
                103
            ]
        },
        {
            "type": "Punctuator",
            "value": "}",
            "loc": {
                "start": {
                    "line": 7,
                    "column": 15
                },
                "end": {
                    "line": 7,
                    "column": 16
                }
            },
            "range": [
                103,
                104
            ]
        },
        {
            "type": "Identifier",
            "value": "async",
            "loc": {
                "start": {
                    "line": 9,
                    "column": 4
                },
                "end": {
                    "line": 9,
                    "column": 9
                }
            },
            "range": [
                110,
                115
            ]
        },
        {
            "type": "Punctuator",
            "value": "*",
            "loc": {
                "start": {
                    "line": 9,
                    "column": 9
                },
                "end": {
                    "line": 9,
                    "column": 10
                }
            },
            "range": [
                115,
                116
            ]
        },
        {
            "type": "PrivateIdentifier",
            "value": "asyncGenerator",
            "loc": {
                "start": {
                    "line": 10,
                    "column": 4
                },
                "end": {
                    "line": 10,
                    "column": 19
                }
            },
            "range": [
                121,
                136
            ]
        },
        {
            "type": "Punctuator",
            "value": "(",
            "loc": {
                "start": {
                    "line": 10,
                    "column": 19
                },
                "end": {
                    "line": 10,
                    "column": 20
                }
            },
            "range": [
                136,
                137
            ]
        },
        {
            "type": "Punctuator",
            "value": ")",
            "loc": {
                "start": {
                    "line": 10,
                    "column": 20
                },
                "end": {
                    "line": 10,
                    "column": 21
                }
            },
            "range": [
                137,
                138
            ]
        },
        {
            "type": "Punctuator",
            "value": "{",
            "loc": {
                "start": {
                    "line": 10,
                    "column": 21
                },
                "end": {
                    "line": 10,
                    "column": 22
                }
            },
            "range": [
                138,
                139
            ]
        },
        {
            "type": "Punctuator",
            "value": "}",
            "loc": {
                "start": {
                    "line": 10,
                    "column": 22
                },
                "end": {
                    "line": 10,
                    "column": 23
                }
            },
            "range": [
                139,
                140
            ]
        },
        {
            "type": "Punctuator",
            "value": "}",
            "loc": {
                "start": {
                    "line": 11,
                    "column": 0
                },
                "end": {
                    "line": 11,
                    "column": 1
                }
            },
            "range": [
                141,
                142
            ]
        }
    ]
};