export default {
    "type": "Program",
    "loc": {
        "start": {
            "line": 1,
            "column": 0
        },
        "end": {
            "line": 6,
            "column": 2
        }
    },
    "range": [
        0,
        53
    ],
    "body": [
        {
            "type": "ExpressionStatement",
            "loc": {
                "start": {
                    "line": 1,
                    "column": 0
                },
                "end": {
                    "line": 1,
                    "column": 13
                }
            },
            "range": [
                0,
                13
            ],
            "directive": "use strict",
            "expression": {
                "type": "Literal",
                "loc": {
                    "start": {
                        "line": 1,
                        "column": 0
                    },
                    "end": {
                        "line": 1,
                        "column": 12
                    }
                },
                "range": [
                    0,
                    12
                ],
                "value": "use strict",
                "raw": "\"use strict\""
            }
        },
        {
            "type": "VariableDeclaration",
            "loc": {
                "start": {
                    "line": 3,
                    "column": 0
                },
                "end": {
                    "line": 6,
                    "column": 2
                }
            },
            "range": [
                15,
                53
            ],
            "declarations": [
                {
                    "type": "VariableDeclarator",
                    "loc": {
                        "start": {
                            "line": 3,
                            "column": 4
                        },
                        "end": {
                            "line": 6,
                            "column": 1
                        }
                    },
                    "range": [
                        19,
                        52
                    ],
                    "id": {
                        "type": "Identifier",
                        "loc": {
                            "start": {
                                "line": 3,
                                "column": 4
                            },
                            "end": {
                                "line": 3,
                                "column": 5
                            }
                        },
                        "range": [
                            19,
                            20
                        ],
                        "name": "x"
                    },
                    "init": {
                        "type": "ObjectExpression",
                        "loc": {
                            "start": {
                                "line": 3,
                                "column": 8
                            },
                            "end": {
                                "line": 6,
                                "column": 1
                            }
                        },
                        "range": [
                            23,
                            52
                        ],
                        "properties": [
                            {
                                "type": "Property",
                                "loc": {
                                    "start": {
                                        "line": 4,
                                        "column": 1
                                    },
                                    "end": {
                                        "line": 4,
                                        "column": 11
                                    }
                                },
                                "range": [
                                    26,
                                    36
                                ],
                                "method": false,
                                "shorthand": false,
                                "computed": false,
                                "key": {
                                    "type": "Identifier",
                                    "loc": {
                                        "start": {
                                            "line": 4,
                                            "column": 1
                                        },
                                        "end": {
                                            "line": 4,
                                            "column": 2
                                        }
                                    },
                                    "range": [
                                        26,
                                        27
                                    ],
                                    "name": "y"
                                },
                                "value": {
                                    "type": "Literal",
                                    "loc": {
                                        "start": {
                                            "line": 4,
                                            "column": 4
                                        },
                                        "end": {
                                            "line": 4,
                                            "column": 11
                                        }
                                    },
                                    "range": [
                                        29,
                                        36
                                    ],
                                    "value": "first",
                                    "raw": "'first'"
                                },
                                "kind": "init"
                            },
                            {
                                "type": "Property",
                                "loc": {
                                    "start": {
                                        "line": 5,
                                        "column": 1
                                    },
                                    "end": {
                                        "line": 5,
                                        "column": 12
                                    }
                                },
                                "range": [
                                    39,
                                    50
                                ],
                                "method": false,
                                "shorthand": false,
                                "computed": false,
                                "key": {
                                    "type": "Identifier",
                                    "loc": {
                                        "start": {
                                            "line": 5,
                                            "column": 1
                                        },
                                        "end": {
                                            "line": 5,
                                            "column": 2
                                        }
                                    },
                                    "range": [
                                        39,
                                        40
                                    ],
                                    "name": "y"
                                },
                                "value": {
                                    "type": "Literal",
                                    "loc": {
                                        "start": {
                                            "line": 5,
                                            "column": 4
                                        },
                                        "end": {
                                            "line": 5,
                                            "column": 12
                                        }
                                    },
                                    "range": [
                                        42,
                                        50
                                    ],
                                    "value": "second",
                                    "raw": "'second'"
                                },
                                "kind": "init"
                            }
                        ]
                    }
                }
            ],
            "kind": "var"
        }
    ],
    "sourceType": "script",
    "tokens": [
        {
            "type": "String",
            "value": "\"use strict\"",
            "loc": {
                "start": {
                    "line": 1,
                    "column": 0
                },
                "end": {
                    "line": 1,
                    "column": 12
                }
            },
            "range": [
                0,
                12
            ]
        },
        {
            "type": "Punctuator",
            "value": ";",
            "loc": {
                "start": {
                    "line": 1,
                    "column": 12
                },
                "end": {
                    "line": 1,
                    "column": 13
                }
            },
            "range": [
                12,
                13
            ]
        },
        {
            "type": "Keyword",
            "value": "var",
            "loc": {
                "start": {
                    "line": 3,
                    "column": 0
                },
                "end": {
                    "line": 3,
                    "column": 3
                }
            },
            "range": [
                15,
                18
            ]
        },
        {
            "type": "Identifier",
            "value": "x",
            "loc": {
                "start": {
                    "line": 3,
                    "column": 4
                },
                "end": {
                    "line": 3,
                    "column": 5
                }
            },
            "range": [
                19,
                20
            ]
        },
        {
            "type": "Punctuator",
            "value": "=",
            "loc": {
                "start": {
                    "line": 3,
                    "column": 6
                },
                "end": {
                    "line": 3,
                    "column": 7
                }
            },
            "range": [
                21,
                22
            ]
        },
        {
            "type": "Punctuator",
            "value": "{",
            "loc": {
                "start": {
                    "line": 3,
                    "column": 8
                },
                "end": {
                    "line": 3,
                    "column": 9
                }
            },
            "range": [
                23,
                24
            ]
        },
        {
            "type": "Identifier",
            "value": "y",
            "loc": {
                "start": {
                    "line": 4,
                    "column": 1
                },
                "end": {
                    "line": 4,
                    "column": 2
                }
            },
            "range": [
                26,
                27
            ]
        },
        {
            "type": "Punctuator",
            "value": ":",
            "loc": {
                "start": {
                    "line": 4,
                    "column": 2
                },
                "end": {
                    "line": 4,
                    "column": 3
                }
            },
            "range": [
                27,
                28
            ]
        },
        {
            "type": "String",
            "value": "'first'",
            "loc": {
                "start": {
                    "line": 4,
                    "column": 4
                },
                "end": {
                    "line": 4,
                    "column": 11
                }
            },
            "range": [
                29,
                36
            ]
        },
        {
            "type": "Punctuator",
            "value": ",",
            "loc": {
                "start": {
                    "line": 4,
                    "column": 11
                },
                "end": {
                    "line": 4,
                    "column": 12
                }
            },
            "range": [
                36,
                37
            ]
        },
        {
            "type": "Identifier",
            "value": "y",
            "loc": {
                "start": {
                    "line": 5,
                    "column": 1
                },
                "end": {
                    "line": 5,
                    "column": 2
                }
            },
            "range": [
                39,
                40
            ]
        },
        {
            "type": "Punctuator",
            "value": ":",
            "loc": {
                "start": {
                    "line": 5,
                    "column": 2
                },
                "end": {
                    "line": 5,
                    "column": 3
                }
            },
            "range": [
                40,
                41
            ]
        },
        {
            "type": "String",
            "value": "'second'",
            "loc": {
                "start": {
                    "line": 5,
                    "column": 4
                },
                "end": {
                    "line": 5,
                    "column": 12
                }
            },
            "range": [
                42,
                50
            ]
        },
        {
            "type": "Punctuator",
            "value": "}",
            "loc": {
                "start": {
                    "line": 6,
                    "column": 0
                },
                "end": {
                    "line": 6,
                    "column": 1
                }
            },
            "range": [
                51,
                52
            ]
        },
        {
            "type": "Punctuator",
            "value": ";",
            "loc": {
                "start": {
                    "line": 6,
                    "column": 1
                },
                "end": {
                    "line": 6,
                    "column": 2
                }
            },
            "range": [
                52,
                53
            ]
        }
    ]
};
